@@ -19,13 +19,15 @@ KERNEL_META_64 = ["linux-generic"]
 PACKAGES_PRE_REMOVALS = []
 
 PACKAGES_ADDITIONS = [
+    "celluloid",
     "fonts-noto-core",
     "gnome-online-accounts-gtk",
+    "hypnotix",
     "pipewire-alsa",
     "pipewire-audio",
     "pipewire-pulse",
+    "simple-scan",
     "systemd-timesyncd",
-    "touchegg",
     "wireplumber",
     "xapp-jxl-thumbnailer",
     "xcvt",
@@ -39,6 +41,7 @@ PACKAGES_REMOVALS = [
     "gstreamer1.0-pulseaudio",
     "ntp",
     "ntpdate",
+    "postfix",
     "pulseaudio",
     "pulseaudio-module-bluetooth",
     "qt5ct",
